@@ -2,7 +2,7 @@
 
 module Telescope.Data.WCS where
 
-import Data.Text
+import Data.Text (Text, pack)
 import GHC.Generics (Generic)
 import Telescope.Data.Axes (AxisOrder (..))
 import Telescope.Data.KnownText
@@ -24,9 +24,9 @@ newtype CType = CType Text deriving (Eq, Show)
 data WCSAxis (alt :: WCSAlt) axis = WCSAxis
   { ctype :: CType
   , cunit :: CUnit
-  , crpix :: Float
-  , crval :: Float
-  , cdelt :: Float
+  , crpix :: Double
+  , crval :: Double
+  , cdelt :: Double
   }
   deriving (Generic, Eq, Show)
 
